==> lxqt-panel-0.15.1.tar.xz: lxqt-panel-0.15.1/plugin-quicklaunch/translations/quicklaunch_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl">
<context>
    <name>LXQtQuickLaunch</name>
    <message>
        <location filename="../lxqtquicklaunch.cpp" line="226"/>
        <source>Drop Error</source>
        <translation>Neerzetfout</translation>
    </message>
    <message>
        <location filename="../lxqtquicklaunch.cpp" line="227"/>
        <source>File/URL &apos;%1&apos; cannot be embedded into QuickLaunch for now</source>
        <translation>Bestand/URL &apos;%1&apos; kan vooralsnog niet worden ingebed in de snelstartbalk</translation>
    </message>
    <message>
        <location filename="../lxqtquicklaunch.cpp" line="333"/>
        <source>Drop application
icons here</source>
        <translation>Zet pictogrammen van
toepassingen hier neer</translation>
    </message>
</context>
<context>
    <name>QuickLaunchButton</name>
    <message>
        <location filename="../quicklaunchbutton.cpp" line="55"/>
        <source>(Ctrl + DND)</source>
        <translation type="unfinished"></translation>
    </message>
    <message>
        <location filename="../quicklaunchbutton.cpp" line="57"/>
        <source>Move left</source>
        <translation>Verplaats naar links</translation>
    </message>
    <message>
        <location filename="../quicklaunchbutton.cpp" line="60"/>
        <source>Move right</source>
        <translation>Verplaats naar rechts</translation>
    </message>
    <message>
        <location filename="../quicklaunchbutton.cpp" line="64"/>
        <source>Remove from quicklaunch</source>
        <translation>Verwijder uit snelstartbalk</translation>
    </message>
</context>
</TS>

==> lxqt-panel_0.16.1.orig.tar.xz: lxqt-panel-0.16.1/plugin-quicklaunch/translations/quicklaunch_nl.ts <==
<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="nl">
<context>
    <name>LXQtQuickLaunch</name>
    <message>
        <location filename="../lxqtquicklaunch.cpp" line="226"/>
        <source>Drop Error</source>
        <translation>Sleepfout</translation>
    </message>
    <message>
        <location filename="../lxqtquicklaunch.cpp" line="227"/>
        <source>File/URL &apos;%1&apos; cannot be embedded into QuickLaunch for now</source>
        <translation>Bestand/URL &apos;%1&apos; kan vooralsnog niet worden ingebed in de snelstartbalk</translation>
    </message>
    <message>
        <location filename="../lxqtquicklaunch.cpp" line="333"/>
        <source>Drop application
icons here</source>
        <translation>Sleep pictogrammen van
toepassingen hiernaartoe</translation>
    </message>
</context>
<context>
    <name>QuickLaunchButton</name>
    <message>
        <location filename="../quicklaunchbutton.cpp" line="55"/>
        <source>(Ctrl + DND)</source>
        <translation>Ctrl + slepen</translation>
    </message>
    <message>
        <location filename="../quicklaunchbutton.cpp" line="57"/>
        <source>Move left</source>
        <translation>Verplaats naar links</translation>
    </message>
    <message>
        <location filename="../quicklaunchbutton.cpp" line="60"/>
        <source>Move right</source>
        <translation>Verplaats naar rechts</translation>
    </message>
    <message>
        <location filename="../quicklaunchbutton.cpp" line="64"/>
        <source>Remove from quicklaunch</source>
        <translation>Verwijder uit snelstarter</translation>
    </message>
</context>
</TS>
